@@ -20,12 +20,14 @@ class Requests(object):
             response = self.pm.request('POST', url, body=data, headers=headers)
             if response.status == 200:
                 return loads(response.data.decode('utf-8'))
-            return False
+            else:
+                return False
         else:
             response = self.pm.request('POST', url, body=dumps(json).encode(), headers={'Content-Type': 'application/json'})
             if response.status == 200:
                 return loads(response.data.decode('utf-8'))
-            return False
+            else:
+                return False
 
     async def uploadFile(self, url, access_hash_send, file_id, byte):
         file_size = len(byte)
@@ -95,6 +97,7 @@ class Requests(object):
                                 raise NotRegistered('Your AUTH is incorrect')
                             elif response.get('status_det') == 'INVALID_INPUT':
                                 raise InvalidInput('The data sent to the server is wrong')
+                            else: raise RuntimeWarning(response)
                         elif response.get('status') == 'OK' and response.get('status_det') == 'OK':
                             response = loads(self.enc.decrypt(response.get('data_enc')))
                             return response
@@ -108,12 +111,12 @@ class Requests(object):
                     response = await self.post(self.getDC(), json=data)
                     if response:
                         response = loads(self.enc.decrypt(response.get('data_enc')))
-                        #print(response)
                         if response.get('status') == 'ERROR_GENERIC':
                             if response.get('status_det') == 'NOT_REGISTERED':
                                 raise NotRegistered('Your AUTH is incorrect')
                             elif response.get('status_det') == 'INVALID_INPUT':
                                 raise InvalidInput('The data sent to the server is wrong')
+                            else: raise RuntimeWarning(response)
                         else:
                             return response
                     else: continue
