@@ -1,8 +1,6 @@
-from Crypto.Cipher.AES import (new)
-from Crypto.Util.Padding import (unpad,
-pad)
-from pybase64 import (b64decode,
-b64encode)
+from Crypto.Cipher.AES import new
+from Crypto.Util.Padding import unpad, pad
+from pybase64 import b64decode, b64encode
 
 
 class Encryption(object):
